@@ -584,7 +584,7 @@ static bool is_devpath_busy(struct event *event) {
         return false;
 }
 
-static void event_queue_start(struct udev *udev) {
+static void event_queue_start(struct udev *udev __attribute__((unused))) {
         struct udev_list_node *loop;
 
         udev_list_node_foreach(loop, &event_list) {
@@ -601,7 +601,7 @@ static void event_queue_start(struct udev *udev) {
         }
 }
 
-static void event_queue_cleanup(struct udev *udev, enum event_state match_type) {
+static void event_queue_cleanup(struct udev *udev __attribute__((unused)), enum event_state match_type) {
         struct udev_list_node *loop, *tmp;
 
         udev_list_node_foreach_safe(loop, tmp, &event_list) {
@@ -920,7 +920,7 @@ static int handle_inotify(struct udev *udev) {
         return 0;
 }
 
-static void handle_signal(struct udev *udev, int signo) {
+static void handle_signal(struct udev *udev __attribute__((unused)), int signo) {
         switch (signo) {
         case SIGINT:
         case SIGTERM:
@@ -1033,13 +1033,13 @@ static void help(void) {
         printf("%s [OPTIONS...]\n\n"
                "Manages devices.\n\n"
                "  -h --help                   Print this message\n"
-               "     --version                Print version of the program\n"
-               "     --daemon                 Detach and run in the background\n"
-               "     --debug                  Enable debug output\n"
-               "     --children-max=INT       Set maximum number of workers\n"
-               "     --exec-delay=SECONDS     Seconds to wait before executing RUN=\n"
-               "     --event-timeout=SECONDS  Seconds to wait before terminating an event\n"
-               "     --resolve-names=early|late|never\n"
+               "  -V --version                Print version of the program\n"
+               "  -d --daemon                 Detach and run in the background\n"
+               "  -D --debug                  Enable debug output\n"
+               "  -c --children-max=INT       Set maximum number of workers\n"
+               "  -e --exec-delay=SECONDS     Seconds to wait before executing RUN=\n"
+               "  -t --event-timeout=SECONDS  Seconds to wait before terminating an event\n"
+               "  -N --resolve-names=early|late|never\n"
                "                              When to resolve users and groups\n"
                , program_invocation_short_name);
 }
@@ -1062,7 +1062,7 @@ static int parse_argv(int argc, char *argv[]) {
         assert(argc >= 0);
         assert(argv);
 
-        while ((c = getopt_long(argc, argv, "c:de:DtN:hV", options, NULL)) >= 0) {
+        while ((c = getopt_long(argc, argv, "c:de:Dt:N:hV", options, NULL)) >= 0) {
                 int r;
 
                 switch (c) {
@@ -1135,6 +1135,22 @@ int main(int argc, char *argv[]) {
         struct epoll_event ep_worker = { .events = EPOLLIN };
         int r = 0, one = 1;
 
+        /*
+         * Ensure no file descriptor unwillingly falls in the 0..2 range
+         * Warning: DO NOT OPEN FILES BEFORE THE 3 OPENS BELOW
+         */
+        int fd_stdi = open("/dev/null", O_RDWR);
+        int fd_stdo = open("/dev/null", O_RDWR);
+        int fd_stde = open("/dev/null", O_RDWR);
+
+        /* Close only the ones that are safe to close */
+        if (fd_stdi > STDERR_FILENO)
+                close(fd_stdi);
+        if (fd_stdo > STDERR_FILENO)
+                close(fd_stdo);
+        if (fd_stde > STDERR_FILENO)
+                close(fd_stde);
+
         udev = udev_new();
         if (!udev) {
                 r = log_error_errno(errno, "could not allocate udev context: %m");
@@ -1152,8 +1168,10 @@ int main(int argc, char *argv[]) {
         if (r < 0)
                 log_warning_errno(r, "failed to parse kernel command line, ignoring: %m");
 
-        if (arg_debug)
+        if (arg_debug) {
+                log_set_target(LOG_TARGET_CONSOLE);
                 log_set_max_level(LOG_DEBUG);
+        }
 
         if (getuid() != 0) {
                 r = log_error_errno(EPERM, "root privileges required");
